organizers = """Alessia Marcolini
Ambra Tonon
Carlo Miron
Edo Abati
Ernesto Arbitrio
Ester Beltrami
Fiorella De Luca
Gionathan Desogus
Juna Salviati
Lelio Campanile
Marco Acierno
Marco Beri
Matteo Benci
Orlando Testa
Paolo Melchiorre
Patrick Arminio
Pietro Peterlongo
Sabrina Scoma
Stefania Delprete
Valerio Maggio"""


def print_team():
    """
    Prints the list of volunteers and encourages people to join the team.
    """
    print("PyCon Italia organizers:")
    print(organizers)

    print("\nWant to be part of the team? Want to help us?")
    print("Write to us at help@pycon.it!")


print_team()
